===========
KATOTTG lib
===========

Quick start
-----------

To be done...

Release notes
-------------

v0.1.0 (2023-06-10)
...................

Initial release.

- Search by name with filter by level (``find_by_name``).
- Search by identifier (``find_by_id``)
